var searchData=
[
  ['scale',['SCALE',['../aqt_8c.html#a0cbea62f1ce2043dd08108e65ed8de1d',1,'aqt.c']]],
  ['setsub',['SETSUB',['../metadefs_8h.html#a5b0117b6132f309a8d5c393433acd3cc',1,'metadefs.h']]],
  ['sign',['SIGN',['../plplotP_8h.html#a8c4a9e5e4622948245de4ec0b5d38329',1,'plplotP.h']]],
  ['sizeof',['SIZEOF',['../cd_8h.html#ab4e7a10b0e2cf79aa0978d3bbe1e1268',1,'cd.h']]],
  ['sizeof_5fdptr',['SIZEOF_DPTR',['../moc__predefs_8h.html#addad5b57ed33bc5c79361574d9e03c06',1,'moc_predefs.h']]],
  ['snprintf',['snprintf',['../plplotP_8h.html#aa367b75c5aed883fef5befbdf04835a4',1,'plplotP.h']]],
  ['snscanf',['snscanf',['../plplotP_8h.html#a690e5d3e324df4a0bcc627f25545943b',1,'plplotP.h']]],
  ['source_5fdir',['SOURCE_DIR',['../plplot__config_8h.html#a9343e0f8dda9d377d1b08b9f7d072d3f',1,'plplot_config.h']]],
  ['ssqr',['SSQR',['../plplotP_8h.html#a527cd260524e42ed5b6c2ba9d638385a',1,'plplotP.h']]],
  ['ssub',['SSUB',['../metadefs_8h.html#ace6b57f62d946947c2de4e67f75fc9bf',1,'metadefs.h']]],
  ['stack_5fninc',['STACK_NINC',['../istack_8c.html#af5988b0fe7080430731e197ab470edac',1,'istack.c']]],
  ['stack_5fnstart',['STACK_NSTART',['../istack_8c.html#aece9764da80b282e99080e969d75d1b0',1,'istack.c']]],
  ['stdc_5fheaders',['STDC_HEADERS',['../plplot__config_8h.html#a550e5c272cc3cf3814651721167dcd23',1,'plplot_config.h']]],
  ['stlen',['STLEN',['../plsym_8c.html#aad5ec696f6c622825db4463e207c9c2a',1,'plsym.c']]],
  ['string_5flen',['STRING_LEN',['../plbox_8c.html#ad6d94ce273637446121c9cbd16b6077f',1,'plbox.c']]],
  ['strncpy',['STRNCPY',['../dirent__msvc_8h.html#a73db8105b4940d803243512f05a3d108',1,'dirent_msvc.h']]],
  ['subpage_5fto_5fadopted_5fx',['subpage_to_adopted_x',['../pllegend_8c.html#a4c3390407d12606208073f331ccbcc12',1,'pllegend.c']]],
  ['subpage_5fto_5fadopted_5fy',['subpage_to_adopted_y',['../pllegend_8c.html#a1f30235419624dc42b2176271f61f542',1,'pllegend.c']]],
  ['surf_5fcont',['SURF_CONT',['../plplot_8h.html#acaa655ac92eaccb02b6b93a739499bcc',1,'plplot.h']]],
  ['svd_5fnmax',['SVD_NMAX',['../csa_8c.html#ab7d1b37f9482ca725f4bd8359e4d4d75',1,'csa.c']]],
  ['svg_5fdefault_5fx',['SVG_Default_X',['../svg_8c.html#a885ab9fab59b6d8bc2cec6828890b2ac',1,'svg.c']]],
  ['svg_5fdefault_5fy',['SVG_Default_Y',['../svg_8c.html#a5f39802ec433b1243cefad6795e2485e',1,'svg.c']]],
  ['swap_5fbalck_5fwhen_5fwhite',['SWAP_BALCK_WHEN_WHITE',['../cgm_8c.html#acbb42fa075a37c6775ae139005bdf9dd',1,'cgm.c']]],
  ['swig_5facquireptr',['SWIG_AcquirePtr',['../plplotcPYTHON__wrap_8c.html#aef3a3f2d1e735f02817fb26d61c8ee3d',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5faddcast',['SWIG_AddCast',['../plplotluacLUA__wrap_8c.html#a4f6f5e0444e44e48aef51f6620438a5f',1,'SWIG_AddCast():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a4f6f5e0444e44e48aef51f6620438a5f',1,'SWIG_AddCast():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a4f6f5e0444e44e48aef51f6620438a5f',1,'SWIG_AddCast():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5faddnewmask',['SWIG_AddNewMask',['../plplotluacLUA__wrap_8c.html#af7ac7e424b623712f70e9b6640a54853',1,'SWIG_AddNewMask():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#af7ac7e424b623712f70e9b6640a54853',1,'SWIG_AddNewMask():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#af7ac7e424b623712f70e9b6640a54853',1,'SWIG_AddNewMask():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5faddtmpmask',['SWIG_AddTmpMask',['../plplotluacLUA__wrap_8c.html#af8527f0123949ec90e05d0fb156c11e3',1,'SWIG_AddTmpMask():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#af8527f0123949ec90e05d0fb156c11e3',1,'SWIG_AddTmpMask():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#af8527f0123949ec90e05d0fb156c11e3',1,'SWIG_AddTmpMask():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5faddvarlink',['SWIG_addvarlink',['../plplotcPYTHON__wrap_8c.html#a49a542a5f7eb7a97541accc2cde0eed9',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5falloc_5farray',['SWIG_ALLOC_ARRAY',['../plplotluacLUA__wrap_8c.html#a0fcc00738845cf2e532f6909f27d54d3',1,'plplotluacLUA_wrap.c']]],
  ['swig_5farg_5ffail',['SWIG_arg_fail',['../plplot__octaveOCTAVE__wrap_8cxx.html#a01ff9379ead152cc27db42716b5aed9f',1,'SWIG_arg_fail():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a01ff9379ead152cc27db42716b5aed9f',1,'SWIG_arg_fail():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fargerror',['SWIG_ArgError',['../plplotluacLUA__wrap_8c.html#a95bab7504841595502bac5ed195becc1',1,'SWIG_ArgError():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a95bab7504841595502bac5ed195becc1',1,'SWIG_ArgError():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a95bab7504841595502bac5ed195becc1',1,'SWIG_ArgError():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fas_5fvoidptr',['SWIG_as_voidptr',['../plplot__octaveOCTAVE__wrap_8cxx.html#a6dc8f6b962375bf647fc53ecbeca2d20',1,'SWIG_as_voidptr():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a6dc8f6b962375bf647fc53ecbeca2d20',1,'SWIG_as_voidptr():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fas_5fvoidptrptr',['SWIG_as_voidptrptr',['../plplot__octaveOCTAVE__wrap_8cxx.html#a46d91724837c8d2846b0b27f8bf1626c',1,'SWIG_as_voidptrptr():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a46d91724837c8d2846b0b27f8bf1626c',1,'SWIG_as_voidptrptr():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fattributeerror',['SWIG_AttributeError',['../plplot__octaveOCTAVE__wrap_8cxx.html#a5c83bd4d8f39d6eed1df7d3444caa2e1',1,'SWIG_AttributeError():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a5c83bd4d8f39d6eed1df7d3444caa2e1',1,'SWIG_AttributeError():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fbadobj',['SWIG_BADOBJ',['../plplotluacLUA__wrap_8c.html#a8268a243a8a840396db70f745c23c37c',1,'SWIG_BADOBJ():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a8268a243a8a840396db70f745c23c37c',1,'SWIG_BADOBJ():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a8268a243a8a840396db70f745c23c37c',1,'SWIG_BADOBJ():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fbinary_5fop',['swig_binary_op',['../plplot__octaveOCTAVE__wrap_8cxx.html#ad8a12a30aa976348f7fde7420c4d5e8e',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['swig_5fbuffer_5fsize',['SWIG_BUFFER_SIZE',['../plplotluacLUA__wrap_8c.html#a26324fcd1baceab72680dfec078da440',1,'SWIG_BUFFER_SIZE():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a26324fcd1baceab72680dfec078da440',1,'SWIG_BUFFER_SIZE():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a26324fcd1baceab72680dfec078da440',1,'SWIG_BUFFER_SIZE():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fbuiltin_5finit',['SWIG_BUILTIN_INIT',['../plplotcPYTHON__wrap_8c.html#aed1090e31bf3997ef5cdce90e61ada96',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fbuiltin_5ftp_5finit',['SWIG_BUILTIN_TP_INIT',['../plplotcPYTHON__wrap_8c.html#ac67ecff3f1af17659582b9a4f90cf532',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fcast_5fnew_5fmemory',['SWIG_CAST_NEW_MEMORY',['../plplotluacLUA__wrap_8c.html#ac8216459bfd45cbd2be36175ef6f1ccc',1,'SWIG_CAST_NEW_MEMORY():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ac8216459bfd45cbd2be36175ef6f1ccc',1,'SWIG_CAST_NEW_MEMORY():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ac8216459bfd45cbd2be36175ef6f1ccc',1,'SWIG_CAST_NEW_MEMORY():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fcastranklimit',['SWIG_CASTRANKLIMIT',['../plplotluacLUA__wrap_8c.html#a2f15c36f8b66185937b8232640be62e4',1,'SWIG_CASTRANKLIMIT():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a2f15c36f8b66185937b8232640be62e4',1,'SWIG_CASTRANKLIMIT():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a2f15c36f8b66185937b8232640be62e4',1,'SWIG_CASTRANKLIMIT():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fcheck_5fnum_5fargs',['SWIG_check_num_args',['../plplotluacLUA__wrap_8c.html#a7e3daad25f96879be557754a9e2ed6b4',1,'plplotluacLUA_wrap.c']]],
  ['swig_5fcheckimplicit',['SWIG_CheckImplicit',['../plplotcPYTHON__wrap_8c.html#acc6f7f7ae2459bfdbe0292aeb22f527e',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fcheckstate',['SWIG_CheckState',['../plplotluacLUA__wrap_8c.html#a1faed8ca17e98c961611bc35fde708a9',1,'SWIG_CheckState():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a1faed8ca17e98c961611bc35fde708a9',1,'SWIG_CheckState():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a1faed8ca17e98c961611bc35fde708a9',1,'SWIG_CheckState():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fcontract_5fassert',['SWIG_contract_assert',['../plplotluacLUA__wrap_8c.html#aca11636b220cff70dac286c268c95ee6',1,'SWIG_contract_assert():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#aca11636b220cff70dac286c268c95ee6',1,'SWIG_contract_assert():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#aca11636b220cff70dac286c268c95ee6',1,'SWIG_contract_assert():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fconvertfunctionptr',['SWIG_ConvertFunctionPtr',['../plplot__octaveOCTAVE__wrap_8cxx.html#a9a8ddc29a77ad0d18dc7d6ca55dd7f92',1,'SWIG_ConvertFunctionPtr():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a9a8ddc29a77ad0d18dc7d6ca55dd7f92',1,'SWIG_ConvertFunctionPtr():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fconvertinstance',['SWIG_ConvertInstance',['../plplotcPYTHON__wrap_8c.html#a55a82f2c2bfcd0c1e514392867a5561c',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fconvertmember',['SWIG_ConvertMember',['../plplotluacLUA__wrap_8c.html#a019c90e4471fdd37ef65653afe55fb5c',1,'SWIG_ConvertMember():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#abb497a1b462ed19945a37c5cffb64de8',1,'SWIG_ConvertMember():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#abb497a1b462ed19945a37c5cffb64de8',1,'SWIG_ConvertMember():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fconvertpacked',['SWIG_ConvertPacked',['../plplot__octaveOCTAVE__wrap_8cxx.html#a870d0838e4e08ed09cb8a5524e91bd56',1,'SWIG_ConvertPacked():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a870d0838e4e08ed09cb8a5524e91bd56',1,'SWIG_ConvertPacked():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fconvertptr',['SWIG_ConvertPtr',['../plplotluacLUA__wrap_8c.html#a3a4e5f587d3994722b0628b2cc96ed42',1,'SWIG_ConvertPtr():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a72b29226ccbfc8ab46f6247435daed44',1,'SWIG_ConvertPtr():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a72b29226ccbfc8ab46f6247435daed44',1,'SWIG_ConvertPtr():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a72b29226ccbfc8ab46f6247435daed44',1,'SWIG_ConvertPtr():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fconvertptrandown',['SWIG_ConvertPtrAndOwn',['../plplot__octaveOCTAVE__wrap_8cxx.html#acf0a954d9ffc3d37abfb95ab3a1639be',1,'SWIG_ConvertPtrAndOwn():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#acf0a954d9ffc3d37abfb95ab3a1639be',1,'SWIG_ConvertPtrAndOwn():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fdeclare_5ftypemap_5farr_5ffn',['SWIG_DECLARE_TYPEMAP_ARR_FN',['../plplotluacLUA__wrap_8c.html#a1955878158ccc192985dc8f572317d2d',1,'plplotluacLUA_wrap.c']]],
  ['swig_5fdefun',['SWIG_DEFUN',['../plplot__octaveOCTAVE__wrap_8cxx.html#a7fad3d3926defa4614f8c3bd5e85fb50',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['swig_5fdelnewmask',['SWIG_DelNewMask',['../plplotluacLUA__wrap_8c.html#ab3ead1d5cb36e1d79daf0bb4732957be',1,'SWIG_DelNewMask():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ab3ead1d5cb36e1d79daf0bb4732957be',1,'SWIG_DelNewMask():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ab3ead1d5cb36e1d79daf0bb4732957be',1,'SWIG_DelNewMask():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fdeltmpmask',['SWIG_DelTmpMask',['../plplotluacLUA__wrap_8c.html#ac08b44ea4ae9f73b19d915969f301a5d',1,'SWIG_DelTmpMask():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ac08b44ea4ae9f73b19d915969f301a5d',1,'SWIG_DelTmpMask():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ac08b44ea4ae9f73b19d915969f301a5d',1,'SWIG_DelTmpMask():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fdivisionbyzero',['SWIG_DivisionByZero',['../plplot__octaveOCTAVE__wrap_8cxx.html#ae4cc0f5599402526dd5c2fdb80d87517',1,'SWIG_DivisionByZero():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ae4cc0f5599402526dd5c2fdb80d87517',1,'SWIG_DivisionByZero():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fdostring_5ffail',['SWIG_DOSTRING_FAIL',['../plplotluacLUA__wrap_8c.html#a054a85a15c821ad190018e106214a1ac',1,'plplotluacLUA_wrap.c']]],
  ['swig_5ferror',['SWIG_ERROR',['../plplotluacLUA__wrap_8c.html#acfa11a770d66f9ca6ba170b173c56c94',1,'SWIG_ERROR():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#acfa11a770d66f9ca6ba170b173c56c94',1,'SWIG_ERROR():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#acfa11a770d66f9ca6ba170b173c56c94',1,'SWIG_ERROR():&#160;plplotcPYTHON_wrap.c'],['../plplotcPYTHON__wrap_8c.html#a01b485cfacae7d870729eea43fb17cb0',1,'SWIG_Error():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5ferrortype',['SWIG_ErrorType',['../plplotcPYTHON__wrap_8c.html#a21d4e75f4bb2519f73467e922c7b51d7',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fexception_5ffail',['SWIG_exception_fail',['../plplot__octaveOCTAVE__wrap_8cxx.html#a567b84b185b0f14620c063787f998109',1,'SWIG_exception_fail():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a567b84b185b0f14620c063787f998109',1,'SWIG_exception_fail():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5ffail',['SWIG_fail',['../plplotluacLUA__wrap_8c.html#ababf56889b69e7a569556eb38cd4f157',1,'SWIG_fail():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ababf56889b69e7a569556eb38cd4f157',1,'SWIG_fail():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ababf56889b69e7a569556eb38cd4f157',1,'SWIG_fail():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5ffail_5farg',['SWIG_fail_arg',['../plplotluacLUA__wrap_8c.html#a41cf11e6c8c4513cbca00772e8aef9fd',1,'plplotluacLUA_wrap.c']]],
  ['swig_5ffail_5fptr',['SWIG_fail_ptr',['../plplotluacLUA__wrap_8c.html#a2075b3c34e15bf3feb67887a633ccddf',1,'plplotluacLUA_wrap.c']]],
  ['swig_5ffree_5farray',['SWIG_FREE_ARRAY',['../plplotluacLUA__wrap_8c.html#a91259e2a735fab35b6364c5e882e8956',1,'plplotluacLUA_wrap.c']]],
  ['swig_5ffrom_5fdouble',['SWIG_From_double',['../plplotcPYTHON__wrap_8c.html#a920116ba77f1ae02cb8ab8730ad22eb9',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fgetmodule',['SWIG_GetModule',['../plplotluacLUA__wrap_8c.html#ab97db3bbfc9e3a73de01e1ee95fa0bb5',1,'SWIG_GetModule():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ab97db3bbfc9e3a73de01e1ee95fa0bb5',1,'SWIG_GetModule():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ab97db3bbfc9e3a73de01e1ee95fa0bb5',1,'SWIG_GetModule():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fglobal_5fname',['SWIG_global_name',['../plplot__octaveOCTAVE__wrap_8cxx.html#a0cd88c05992aac88a4bac44ae50d5520',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['swig_5findexerror',['SWIG_IndexError',['../plplot__octaveOCTAVE__wrap_8cxx.html#af1ed73e454bdee28cc19369784f56eed',1,'SWIG_IndexError():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#af1ed73e454bdee28cc19369784f56eed',1,'SWIG_IndexError():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5finit',['SWIG_init',['../plplotluacLUA__wrap_8c.html#a2d71dac1020240ec6993bfc5048a5988',1,'SWIG_init():&#160;plplotluacLUA_wrap.c'],['../plplotcPYTHON__wrap_8c.html#a2d71dac1020240ec6993bfc5048a5988',1,'SWIG_init():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5finit_5fuser',['SWIG_init_user',['../plplotluacLUA__wrap_8c.html#abff8d88e576deb392ba2834eb7d4ad96',1,'plplotluacLUA_wrap.c']]],
  ['swig_5finstallconstants',['SWIG_InstallConstants',['../plplotcPYTHON__wrap_8c.html#a9d393ea973fc8a2e2672e885ec06221b',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5finternalnewpointerobj',['SWIG_InternalNewPointerObj',['../plplotcPYTHON__wrap_8c.html#a53f02e00ff4e64a8c3e354a0b6aaf0a8',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fioerror',['SWIG_IOError',['../plplot__octaveOCTAVE__wrap_8cxx.html#a9fcdfcd79ad6f30120990223ea16879a',1,'SWIG_IOError():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a9fcdfcd79ad6f30120990223ea16879a',1,'SWIG_IOError():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fisnewobj',['SWIG_IsNewObj',['../plplotluacLUA__wrap_8c.html#a5246ae38052e6fa0e3cca2026cdda153',1,'SWIG_IsNewObj():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a5246ae38052e6fa0e3cca2026cdda153',1,'SWIG_IsNewObj():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a5246ae38052e6fa0e3cca2026cdda153',1,'SWIG_IsNewObj():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fisok',['SWIG_IsOK',['../plplotluacLUA__wrap_8c.html#aea8ef410fde907633cb76d9d18131fa1',1,'SWIG_IsOK():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#aea8ef410fde907633cb76d9d18131fa1',1,'SWIG_IsOK():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#aea8ef410fde907633cb76d9d18131fa1',1,'SWIG_IsOK():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fisptrtype',['SWIG_isptrtype',['../plplotluacLUA__wrap_8c.html#ac24315f20782462ad057bf1c8309a616',1,'plplotluacLUA_wrap.c']]],
  ['swig_5fistmpobj',['SWIG_IsTmpObj',['../plplotluacLUA__wrap_8c.html#aa8f2563a536468b40dc33843d4bb7efe',1,'SWIG_IsTmpObj():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#aa8f2563a536468b40dc33843d4bb7efe',1,'SWIG_IsTmpObj():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#aa8f2563a536468b40dc33843d4bb7efe',1,'SWIG_IsTmpObj():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5flua_5fadd_5fboolean',['SWIG_Lua_add_boolean',['../plplotluacLUA__wrap_8c.html#afd5580acc2cb0c0eeaf0644bac06f99e',1,'plplotluacLUA_wrap.c']]],
  ['swig_5flua_5fadd_5ffunction',['SWIG_Lua_add_function',['../plplotluacLUA__wrap_8c.html#a4e0088e1d53848f80738e5a49f1c0cf3',1,'plplotluacLUA_wrap.c']]],
  ['swig_5flua_5fbinary',['SWIG_LUA_BINARY',['../plplotluacLUA__wrap_8c.html#af2062cfc3a6907d38c2587cdab77ae38',1,'plplotluacLUA_wrap.c']]],
  ['swig_5flua_5fchar',['SWIG_LUA_CHAR',['../plplotluacLUA__wrap_8c.html#a50c58df5c9bd1cea902021a7f7fc9896',1,'plplotluacLUA_wrap.c']]],
  ['swig_5flua_5fconsttab_5fbinary',['SWIG_LUA_CONSTTAB_BINARY',['../plplotluacLUA__wrap_8c.html#a38564dfb0235d7ba0f543836919b6dac',1,'plplotluacLUA_wrap.c']]],
  ['swig_5flua_5fconsttab_5fchar',['SWIG_LUA_CONSTTAB_CHAR',['../plplotluacLUA__wrap_8c.html#af21b898b6e053c8bb73855969e0888b0',1,'plplotluacLUA_wrap.c']]],
  ['swig_5flua_5fconsttab_5ffloat',['SWIG_LUA_CONSTTAB_FLOAT',['../plplotluacLUA__wrap_8c.html#a86474eb3525b32c80966dde2330e9596',1,'plplotluacLUA_wrap.c']]],
  ['swig_5flua_5fconsttab_5fint',['SWIG_LUA_CONSTTAB_INT',['../plplotluacLUA__wrap_8c.html#a81533fe9e3e23fc8a0caad2a15ddc953',1,'plplotluacLUA_wrap.c']]],
  ['swig_5flua_5fconsttab_5fpointer',['SWIG_LUA_CONSTTAB_POINTER',['../plplotluacLUA__wrap_8c.html#ab5c3df1096e1d0596e6401e9aaf91f4b',1,'plplotluacLUA_wrap.c']]],
  ['swig_5flua_5fconsttab_5fstring',['SWIG_LUA_CONSTTAB_STRING',['../plplotluacLUA__wrap_8c.html#a9bcdad1f49921f12301ceb55b31f7f48',1,'plplotluacLUA_wrap.c']]],
  ['swig_5flua_5fflavor_5felua',['SWIG_LUA_FLAVOR_ELUA',['../plplotluacLUA__wrap_8c.html#a00a6f75261552001dd1ac741f712d82f',1,'plplotluacLUA_wrap.c']]],
  ['swig_5flua_5fflavor_5feluac',['SWIG_LUA_FLAVOR_ELUAC',['../plplotluacLUA__wrap_8c.html#a351d33087485b24840afe357df576385',1,'plplotluacLUA_wrap.c']]],
  ['swig_5flua_5fflavor_5flua',['SWIG_LUA_FLAVOR_LUA',['../plplotluacLUA__wrap_8c.html#a6e2b880437634cb73e882be20de53d32',1,'plplotluacLUA_wrap.c']]],
  ['swig_5flua_5ffloat',['SWIG_LUA_FLOAT',['../plplotluacLUA__wrap_8c.html#a9c4ea7e25de05f5a501e7163fd480b67',1,'plplotluacLUA_wrap.c']]],
  ['swig_5flua_5fget_5ftable',['SWIG_Lua_get_table',['../plplotluacLUA__wrap_8c.html#a45e06ea798b759df9853467b13abcdfc',1,'plplotluacLUA_wrap.c']]],
  ['swig_5flua_5fint',['SWIG_LUA_INT',['../plplotluacLUA__wrap_8c.html#ae486ba0f8ccf6c87507633344d3f6a96',1,'plplotluacLUA_wrap.c']]],
  ['swig_5flua_5fmodule_5fglobal',['SWIG_LUA_MODULE_GLOBAL',['../plplotluacLUA__wrap_8c.html#a9ea8dbda85958ffd0de0a8535b59cc6f',1,'plplotluacLUA_wrap.c']]],
  ['swig_5flua_5fpointer',['SWIG_LUA_POINTER',['../plplotluacLUA__wrap_8c.html#a2f4d58f9ce413585253063575c033082',1,'plplotluacLUA_wrap.c']]],
  ['swig_5flua_5fstring',['SWIG_LUA_STRING',['../plplotluacLUA__wrap_8c.html#af6a25edb9ad2ab838e1b1fa3e4450121',1,'plplotluacLUA_wrap.c']]],
  ['swig_5flua_5ftarget',['SWIG_LUA_TARGET',['../plplotluacLUA__wrap_8c.html#a84d911ffa9c41b3a66cc7e7d3645671f',1,'plplotluacLUA_wrap.c']]],
  ['swig_5fluacode',['SWIG_LUACODE',['../plplotluacLUA__wrap_8c.html#ae414a798047560c2492aedd86b78beb9',1,'plplotluacLUA_wrap.c']]],
  ['swig_5fmangledtypequery',['SWIG_MangledTypeQuery',['../plplotluacLUA__wrap_8c.html#a0ca9dc37d343186a34e966b5a8649ac0',1,'SWIG_MangledTypeQuery():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a0ca9dc37d343186a34e966b5a8649ac0',1,'SWIG_MangledTypeQuery():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a0ca9dc37d343186a34e966b5a8649ac0',1,'SWIG_MangledTypeQuery():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fmemoryerror',['SWIG_MemoryError',['../plplot__octaveOCTAVE__wrap_8cxx.html#ae1cd9de0a75c6d814815a9de66a4a46d',1,'SWIG_MemoryError():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ae1cd9de0a75c6d814815a9de66a4a46d',1,'SWIG_MemoryError():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fmodule_5fclientdata_5ftype',['SWIG_MODULE_CLIENTDATA_TYPE',['../plplotluacLUA__wrap_8c.html#a50d0a80dccc1d34749f07c82d6a04169',1,'SWIG_MODULE_CLIENTDATA_TYPE():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a50d0a80dccc1d34749f07c82d6a04169',1,'SWIG_MODULE_CLIENTDATA_TYPE():&#160;plplot_octaveOCTAVE_wrap.cxx']]],
  ['swig_5fmustgetptr',['SWIG_MustGetPtr',['../plplotluacLUA__wrap_8c.html#a59f926cc14b21f2e478ac27541df0162',1,'SWIG_MustGetPtr():&#160;plplotluacLUA_wrap.c'],['../plplotcPYTHON__wrap_8c.html#a3b25c4552307e2b3cd5d322ff6b0c294',1,'SWIG_MustGetPtr():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fname',['SWIG_name',['../plplotluacLUA__wrap_8c.html#acff905e8f0880e6e5bba1495c416a6af',1,'SWIG_name():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#acff905e8f0880e6e5bba1495c416a6af',1,'SWIG_name():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#acff905e8f0880e6e5bba1495c416a6af',1,'SWIG_name():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fname_5fd',['SWIG_name_d',['../plplot__octaveOCTAVE__wrap_8cxx.html#a51bd3fade0d8541deb41762a781956ec',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['swig_5fnewclientdata',['SWIG_NewClientData',['../plplotcPYTHON__wrap_8c.html#a3b999f80821e34ecc8bded97723003fd',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fnewfunctionptrobj',['SWIG_NewFunctionPtrObj',['../plplot__octaveOCTAVE__wrap_8cxx.html#aab2f1993f97bd27040adf9836dafff18',1,'SWIG_NewFunctionPtrObj():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#aab2f1993f97bd27040adf9836dafff18',1,'SWIG_NewFunctionPtrObj():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fnewinstanceobj',['SWIG_NewInstanceObj',['../plplotcPYTHON__wrap_8c.html#a27e06002d6d8728005edd12c144444c3',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fnewmemberobj',['SWIG_NewMemberObj',['../plplotluacLUA__wrap_8c.html#a20c6437f49ae257857683ba0e7b2100f',1,'SWIG_NewMemberObj():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a4b628289fae4cd1c4ee9be55e1927f65',1,'SWIG_NewMemberObj():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a4b628289fae4cd1c4ee9be55e1927f65',1,'SWIG_NewMemberObj():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fnewobj',['SWIG_NEWOBJ',['../plplotluacLUA__wrap_8c.html#ab00ef4fde02a6d8d9653ea9edb28d3c9',1,'SWIG_NEWOBJ():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ab00ef4fde02a6d8d9653ea9edb28d3c9',1,'SWIG_NEWOBJ():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ab00ef4fde02a6d8d9653ea9edb28d3c9',1,'SWIG_NEWOBJ():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fnewobjmask',['SWIG_NEWOBJMASK',['../plplotluacLUA__wrap_8c.html#a0021b435c31c3ab285b5a6f4547719e3',1,'SWIG_NEWOBJMASK():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a0021b435c31c3ab285b5a6f4547719e3',1,'SWIG_NEWOBJMASK():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a0021b435c31c3ab285b5a6f4547719e3',1,'SWIG_NEWOBJMASK():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fnewpackedobj',['SWIG_NewPackedObj',['../plplot__octaveOCTAVE__wrap_8cxx.html#ab6d4285e098e13c5797188b2cf77592e',1,'SWIG_NewPackedObj():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ab6d4285e098e13c5797188b2cf77592e',1,'SWIG_NewPackedObj():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fnewpointerobj',['SWIG_NewPointerObj',['../plplotluacLUA__wrap_8c.html#a8eb06167550295873af166db6a49cf36',1,'SWIG_NewPointerObj():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a978ff8eb5e32b08b8a1b8399c1994f23',1,'SWIG_NewPointerObj():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a978ff8eb5e32b08b8a1b8399c1994f23',1,'SWIG_NewPointerObj():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fnewvarlink',['SWIG_newvarlink',['../plplotcPYTHON__wrap_8c.html#a840e0b11d64ac8d72e9f72d518cc67be',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fnullreferenceerror',['SWIG_NullReferenceError',['../plplot__octaveOCTAVE__wrap_8cxx.html#aa11fe417abd4c5a02d31cc1a51dee007',1,'SWIG_NullReferenceError():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#aa11fe417abd4c5a02d31cc1a51dee007',1,'SWIG_NullReferenceError():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5foctave_5fadderrormsg',['SWIG_Octave_AddErrorMsg',['../plplot__octaveOCTAVE__wrap_8cxx.html#a074b6a028433944b362f531ee7a7fa5f',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['swig_5foctave_5fbound_5ffunc',['SWIG_OCTAVE_BOUND_FUNC',['../plplot__octaveOCTAVE__wrap_8cxx.html#a57694a6e3a7e13e344fb5828a78fbb25',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['swig_5foctave_5fconvertptr',['SWIG_Octave_ConvertPtr',['../plplot__octaveOCTAVE__wrap_8cxx.html#a059ec983f00a9ff600d30f35b72b1737',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['swig_5foctave_5fprereq',['SWIG_OCTAVE_PREREQ',['../plplot__octaveOCTAVE__wrap_8cxx.html#a448761d7811a0a61bd974332adf5ea77',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['swig_5fok',['SWIG_OK',['../plplotluacLUA__wrap_8c.html#af9ecbac56d4c5cd6104ae8f6bb82e9f7',1,'SWIG_OK():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#af9ecbac56d4c5cd6104ae8f6bb82e9f7',1,'SWIG_OK():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#af9ecbac56d4c5cd6104ae8f6bb82e9f7',1,'SWIG_OK():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5foldobj',['SWIG_OLDOBJ',['../plplotluacLUA__wrap_8c.html#a4afcf490ff5b4abbca27ca23d9af288e',1,'SWIG_OLDOBJ():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a4afcf490ff5b4abbca27ca23d9af288e',1,'SWIG_OLDOBJ():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a4afcf490ff5b4abbca27ca23d9af288e',1,'SWIG_OLDOBJ():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fop_5fprefix',['SWIG_op_prefix',['../plplot__octaveOCTAVE__wrap_8cxx.html#a92d38f42f6f1e9aef0b57bd89a92d542',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['swig_5foverflowerror',['SWIG_OverflowError',['../plplot__octaveOCTAVE__wrap_8cxx.html#ae9c11d011d8390489595f718d7565a8a',1,'SWIG_OverflowError():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ae9c11d011d8390489595f718d7565a8a',1,'SWIG_OverflowError():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fowntype',['swig_owntype',['../plplot__octaveOCTAVE__wrap_8cxx.html#ae8afee2b61d8b25aa291dc9574882369',1,'swig_owntype():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ae8afee2b61d8b25aa291dc9574882369',1,'swig_owntype():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fpointer_5fdisown',['SWIG_POINTER_DISOWN',['../plplotluacLUA__wrap_8c.html#aa56139a289829795ed651d533826b65e',1,'SWIG_POINTER_DISOWN():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#aa56139a289829795ed651d533826b65e',1,'SWIG_POINTER_DISOWN():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#aa56139a289829795ed651d533826b65e',1,'SWIG_POINTER_DISOWN():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fpointer_5fexception',['SWIG_POINTER_EXCEPTION',['../plplot__octaveOCTAVE__wrap_8cxx.html#a1ad28578247a49297256a8d36c015f3f',1,'SWIG_POINTER_EXCEPTION():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a1ad28578247a49297256a8d36c015f3f',1,'SWIG_POINTER_EXCEPTION():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fpointer_5fimplicit_5fconv',['SWIG_POINTER_IMPLICIT_CONV',['../plplotcPYTHON__wrap_8c.html#a28a70d0513a11dd60735baa8e09c9e44',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fpointer_5fnew',['SWIG_POINTER_NEW',['../plplotcPYTHON__wrap_8c.html#a1d7a891b8fceac04d0954a0e7aaf7d1c',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fpointer_5fnoshadow',['SWIG_POINTER_NOSHADOW',['../plplotcPYTHON__wrap_8c.html#a4a923a6f2e1436eab52ac29421cb2831',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fpointer_5fown',['SWIG_POINTER_OWN',['../plplotluacLUA__wrap_8c.html#a1a125b0e9c551bb9cdeb21b8e5be5b57',1,'SWIG_POINTER_OWN():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a1a125b0e9c551bb9cdeb21b8e5be5b57',1,'SWIG_POINTER_OWN():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a1a125b0e9c551bb9cdeb21b8e5be5b57',1,'SWIG_POINTER_OWN():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fpy_5fbinary',['SWIG_PY_BINARY',['../plplotcPYTHON__wrap_8c.html#a45cd68c9cc0396e2f8c16cc1b50f8c6f',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fpy_5fpointer',['SWIG_PY_POINTER',['../plplotcPYTHON__wrap_8c.html#a2c3773038cfb197d2d3bf29b9efa4073',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fpybuffer_5fsize',['SWIG_PYBUFFER_SIZE',['../plplotcPYTHON__wrap_8c.html#ad604946e2c4cd420d591cd0d4ab95a59',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fpython_5fcallfunctor',['SWIG_Python_CallFunctor',['../plplotcPYTHON__wrap_8c.html#a709f9240049521dd53af4010e5775ecd',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fpython_5fconvertptr',['SWIG_Python_ConvertPtr',['../plplotcPYTHON__wrap_8c.html#a317c93ceaadae6337607e6d58da351f6',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fpython_5fdirector_5fno_5fvtable',['SWIG_PYTHON_DIRECTOR_NO_VTABLE',['../plplotcPYTHON__wrap_8c.html#ac0f9be2b78eb4770640a820a365e968e',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fpython_5finitialize_5fthreads',['SWIG_PYTHON_INITIALIZE_THREADS',['../plplotcPYTHON__wrap_8c.html#af5f88d8a220c62e7ee2604ebaf37b920',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fpython_5fraise',['SWIG_Python_Raise',['../plplotcPYTHON__wrap_8c.html#ab44c6be9067567689102ab757dad6ea0',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fpython_5fstr_5fdelforpy3',['SWIG_Python_str_DelForPy3',['../plplotcPYTHON__wrap_8c.html#a866b998f49f1870f2a0af8e30c738d15',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fpython_5fstr_5ffromformat',['SWIG_Python_str_FromFormat',['../plplotcPYTHON__wrap_8c.html#a9b793ab094535913288a25a20906bc8e',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fpython_5fthread_5fbegin_5fallow',['SWIG_PYTHON_THREAD_BEGIN_ALLOW',['../plplotcPYTHON__wrap_8c.html#afcf771f05d7d2e2508d33c729ed06df9',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fpython_5fthread_5fbegin_5fblock',['SWIG_PYTHON_THREAD_BEGIN_BLOCK',['../plplotcPYTHON__wrap_8c.html#afc4dd083ffcb3bc22ea34b1f3c4afd7c',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fpython_5fthread_5fend_5fallow',['SWIG_PYTHON_THREAD_END_ALLOW',['../plplotcPYTHON__wrap_8c.html#acbaf738de1eb9d87f30c14046482544f',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fpython_5fthread_5fend_5fblock',['SWIG_PYTHON_THREAD_END_BLOCK',['../plplotcPYTHON__wrap_8c.html#a320aff2875f19ba4cfb71eefd84fd618',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fruntime_5fversion',['SWIG_RUNTIME_VERSION',['../plplotluacLUA__wrap_8c.html#a4895907de5539551925ab5c03ea05d28',1,'SWIG_RUNTIME_VERSION():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a4895907de5539551925ab5c03ea05d28',1,'SWIG_RUNTIME_VERSION():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a4895907de5539551925ab5c03ea05d28',1,'SWIG_RUNTIME_VERSION():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fruntimeerror',['SWIG_RuntimeError',['../plplot__octaveOCTAVE__wrap_8cxx.html#a34d3d1c1310427d00140bf1cc8de3ef6',1,'SWIG_RuntimeError():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a34d3d1c1310427d00140bf1cc8de3ef6',1,'SWIG_RuntimeError():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fseterrormsg',['SWIG_SetErrorMsg',['../plplotcPYTHON__wrap_8c.html#a47f0648c02682836188562820e28e9c5',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fseterrorobj',['SWIG_SetErrorObj',['../plplotcPYTHON__wrap_8c.html#a874120d0e9be7616d706e1bfe98cfe6f',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fsetmodule',['SWIG_SetModule',['../plplotluacLUA__wrap_8c.html#a673a7dcc5c15f5cffa7072785a6c7972',1,'SWIG_SetModule():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a673a7dcc5c15f5cffa7072785a6c7972',1,'SWIG_SetModule():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a673a7dcc5c15f5cffa7072785a6c7972',1,'SWIG_SetModule():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fstatic_5fpointer',['SWIG_STATIC_POINTER',['../plplotcPYTHON__wrap_8c.html#aa58fdef163810db36a21536e3fef11fc',1,'plplotcPYTHON_wrap.c']]],
  ['swig_5fsyntaxerror',['SWIG_SyntaxError',['../plplot__octaveOCTAVE__wrap_8cxx.html#a1c4e29c043d3220cedca539360e07148',1,'SWIG_SyntaxError():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a1c4e29c043d3220cedca539360e07148',1,'SWIG_SyntaxError():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fsystemerror',['SWIG_SystemError',['../plplot__octaveOCTAVE__wrap_8cxx.html#ae4a7b4ce78e031cbf5227bea38d81221',1,'SWIG_SystemError():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ae4a7b4ce78e031cbf5227bea38d81221',1,'SWIG_SystemError():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5ftmpobj',['SWIG_TMPOBJ',['../plplotluacLUA__wrap_8c.html#ab1fe70ae34b39b709eb4cfb084862236',1,'SWIG_TMPOBJ():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ab1fe70ae34b39b709eb4cfb084862236',1,'SWIG_TMPOBJ():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ab1fe70ae34b39b709eb4cfb084862236',1,'SWIG_TMPOBJ():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5ftmpobjmask',['SWIG_TMPOBJMASK',['../plplotluacLUA__wrap_8c.html#a399dafc6302bd9b309041d5570ae94c9',1,'SWIG_TMPOBJMASK():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a399dafc6302bd9b309041d5570ae94c9',1,'SWIG_TMPOBJMASK():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a399dafc6302bd9b309041d5570ae94c9',1,'SWIG_TMPOBJMASK():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5ftype_5ftable_5fname',['SWIG_TYPE_TABLE_NAME',['../plplotluacLUA__wrap_8c.html#ac619a84edecccb5e00c1b4a3180b8c3a',1,'SWIG_TYPE_TABLE_NAME():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ac619a84edecccb5e00c1b4a3180b8c3a',1,'SWIG_TYPE_TABLE_NAME():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ac619a84edecccb5e00c1b4a3180b8c3a',1,'SWIG_TYPE_TABLE_NAME():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5ftypeerror',['SWIG_TypeError',['../plplot__octaveOCTAVE__wrap_8cxx.html#a2685345a18f9d5fe8a390ec8500cb916',1,'SWIG_TypeError():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a2685345a18f9d5fe8a390ec8500cb916',1,'SWIG_TypeError():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5ftypequery',['SWIG_TypeQuery',['../plplotluacLUA__wrap_8c.html#a184d005bbcde85bc7d3f652de20d10b3',1,'SWIG_TypeQuery():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a184d005bbcde85bc7d3f652de20d10b3',1,'SWIG_TypeQuery():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a184d005bbcde85bc7d3f652de20d10b3',1,'SWIG_TypeQuery():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5funary_5fop',['swig_unary_op',['../plplot__octaveOCTAVE__wrap_8cxx.html#a3fe86959005f6ce39133b2db2cac0dec',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['swig_5funknownerror',['SWIG_UnknownError',['../plplot__octaveOCTAVE__wrap_8cxx.html#a45817cd389e6f40d0ffb004ff0678031',1,'SWIG_UnknownError():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a45817cd389e6f40d0ffb004ff0678031',1,'SWIG_UnknownError():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fvalueerror',['SWIG_ValueError',['../plplot__octaveOCTAVE__wrap_8cxx.html#a4c1b15a2401d60351d98df9327886280',1,'SWIG_ValueError():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a4c1b15a2401d60351d98df9327886280',1,'SWIG_ValueError():&#160;plplotcPYTHON_wrap.c']]],
  ['swig_5fversion',['SWIG_VERSION',['../plplot__octaveOCTAVE__wrap_8cxx.html#a8180a5d9a951bc3a9c5852fce5fde4e8',1,'SWIG_VERSION():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a8180a5d9a951bc3a9c5852fce5fde4e8',1,'SWIG_VERSION():&#160;plplotcPYTHON_wrap.c']]],
  ['swigexport',['SWIGEXPORT',['../plplotluacLUA__wrap_8c.html#aea3c8b056dcc8c1ab93f6b825cd1371b',1,'SWIGEXPORT():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#aea3c8b056dcc8c1ab93f6b825cd1371b',1,'SWIGEXPORT():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#aea3c8b056dcc8c1ab93f6b825cd1371b',1,'SWIGEXPORT():&#160;plplotcPYTHON_wrap.c']]],
  ['swiginline',['SWIGINLINE',['../plplotluacLUA__wrap_8c.html#a6d0a7c65b3712775e92c8bdb7acdd0ee',1,'SWIGINLINE():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a6d0a7c65b3712775e92c8bdb7acdd0ee',1,'SWIGINLINE():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a6d0a7c65b3712775e92c8bdb7acdd0ee',1,'SWIGINLINE():&#160;plplotcPYTHON_wrap.c']]],
  ['swigintern',['SWIGINTERN',['../plplotluacLUA__wrap_8c.html#a8f2319f775e5b9d5906c9ef25d9b819a',1,'SWIGINTERN():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a8f2319f775e5b9d5906c9ef25d9b819a',1,'SWIGINTERN():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a8f2319f775e5b9d5906c9ef25d9b819a',1,'SWIGINTERN():&#160;plplotcPYTHON_wrap.c']]],
  ['swiginterninline',['SWIGINTERNINLINE',['../plplotluacLUA__wrap_8c.html#afc5b08bb3c3cd2e3fb2e34b775346153',1,'SWIGINTERNINLINE():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#afc5b08bb3c3cd2e3fb2e34b775346153',1,'SWIGINTERNINLINE():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#afc5b08bb3c3cd2e3fb2e34b775346153',1,'SWIGINTERNINLINE():&#160;plplotcPYTHON_wrap.c']]],
  ['swiglua',['SWIGLUA',['../plplotluacLUA__wrap_8c.html#a2766a62201ede45a8bce1856f083d631',1,'plplotluacLUA_wrap.c']]],
  ['swigoctave',['SWIGOCTAVE',['../plplot__octaveOCTAVE__wrap_8cxx.html#ad6fb3697f46e722ef7dffdabeffcaf5b',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['swigpython',['SWIGPYTHON',['../plplotcPYTHON__wrap_8c.html#a8db301777472eabaccb1d609dcedb54e',1,'plplotcPYTHON_wrap.c']]],
  ['swigreg_5fbinary_5fop',['swigreg_binary_op',['../plplot__octaveOCTAVE__wrap_8cxx.html#a4515ab036c2b836726a1824ada77ffdf',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['swigreg_5funary_5fop',['swigreg_unary_op',['../plplot__octaveOCTAVE__wrap_8cxx.html#a614956ae75cf02dc774786ebd69c165e',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['swigruntime',['SWIGRUNTIME',['../plplotluacLUA__wrap_8c.html#a42cd9c1d67d803040a3e78515945afcb',1,'SWIGRUNTIME():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a42cd9c1d67d803040a3e78515945afcb',1,'SWIGRUNTIME():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a42cd9c1d67d803040a3e78515945afcb',1,'SWIGRUNTIME():&#160;plplotcPYTHON_wrap.c']]],
  ['swigruntimeinline',['SWIGRUNTIMEINLINE',['../plplotluacLUA__wrap_8c.html#affa7aa2bcce5bea24a20e5b184ae0533',1,'SWIGRUNTIMEINLINE():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#affa7aa2bcce5bea24a20e5b184ae0533',1,'SWIGRUNTIMEINLINE():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#affa7aa2bcce5bea24a20e5b184ae0533',1,'SWIGRUNTIMEINLINE():&#160;plplotcPYTHON_wrap.c']]],
  ['swigstdcall',['SWIGSTDCALL',['../plplotluacLUA__wrap_8c.html#adcd6410456ea7a76147d3ad95b9bcb36',1,'SWIGSTDCALL():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#adcd6410456ea7a76147d3ad95b9bcb36',1,'SWIGSTDCALL():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#adcd6410456ea7a76147d3ad95b9bcb36',1,'SWIGSTDCALL():&#160;plplotcPYTHON_wrap.c']]],
  ['swigtemplatedisambiguator',['SWIGTEMPLATEDISAMBIGUATOR',['../plplotluacLUA__wrap_8c.html#a7e84031693895e512662f5b390c6d0e4',1,'SWIGTEMPLATEDISAMBIGUATOR():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a7e84031693895e512662f5b390c6d0e4',1,'SWIGTEMPLATEDISAMBIGUATOR():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a7e84031693895e512662f5b390c6d0e4',1,'SWIGTEMPLATEDISAMBIGUATOR():&#160;plplotcPYTHON_wrap.c']]],
  ['swigtype_5fp_5fchar',['SWIGTYPE_p_char',['../plplotluacLUA__wrap_8c.html#a4fea528f7738d5fc0e2f14911d2b9d38',1,'SWIGTYPE_p_char():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a4fea528f7738d5fc0e2f14911d2b9d38',1,'SWIGTYPE_p_char():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a4fea528f7738d5fc0e2f14911d2b9d38',1,'SWIGTYPE_p_char():&#160;plplotcPYTHON_wrap.c']]],
  ['swigtype_5fp_5fdouble',['SWIGTYPE_p_double',['../plplotluacLUA__wrap_8c.html#ae614b9773454184a45966a0750727b9d',1,'SWIGTYPE_p_double():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ae614b9773454184a45966a0750727b9d',1,'SWIGTYPE_p_double():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ae614b9773454184a45966a0750727b9d',1,'SWIGTYPE_p_double():&#160;plplotcPYTHON_wrap.c']]],
  ['swigtype_5fp_5ff_5fdouble_5fdouble_5f_5fint',['SWIGTYPE_p_f_double_double__int',['../plplotluacLUA__wrap_8c.html#af0600c84bffb86e3577df30fe36d3425',1,'SWIGTYPE_p_f_double_double__int():&#160;plplotluacLUA_wrap.c'],['../plplotcPYTHON__wrap_8c.html#af0600c84bffb86e3577df30fe36d3425',1,'SWIGTYPE_p_f_double_double__int():&#160;plplotcPYTHON_wrap.c']]],
  ['swigtype_5fp_5ff_5fdouble_5fdouble_5fp_5fdouble_5fp_5fdouble_5fp_5fvoid_5f_5fvoid',['SWIGTYPE_p_f_double_double_p_double_p_double_p_void__void',['../plplotluacLUA__wrap_8c.html#a48b31267a66347025b9c355ccfbd54a9',1,'SWIGTYPE_p_f_double_double_p_double_p_double_p_void__void():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a48b31267a66347025b9c355ccfbd54a9',1,'SWIGTYPE_p_f_double_double_p_double_p_double_p_void__void():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a48b31267a66347025b9c355ccfbd54a9',1,'SWIGTYPE_p_f_double_double_p_double_p_double_p_void__void():&#160;plplotcPYTHON_wrap.c']]],
  ['swigtype_5fp_5ff_5fint_5fdouble_5fp_5fchar_5fint_5fp_5fvoid_5f_5fvoid',['SWIGTYPE_p_f_int_double_p_char_int_p_void__void',['../plplotluacLUA__wrap_8c.html#ad7e79c86e7c871c2e72af2844fbf46d9',1,'SWIGTYPE_p_f_int_double_p_char_int_p_void__void():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ad7e79c86e7c871c2e72af2844fbf46d9',1,'SWIGTYPE_p_f_int_double_p_char_int_p_void__void():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ad7e79c86e7c871c2e72af2844fbf46d9',1,'SWIGTYPE_p_f_int_double_p_char_int_p_void__void():&#160;plplotcPYTHON_wrap.c']]],
  ['swigtype_5fp_5ff_5fint_5fp_5fdouble_5fp_5fdouble_5f_5fvoid',['SWIGTYPE_p_f_int_p_double_p_double__void',['../plplotluacLUA__wrap_8c.html#ae94c3b6e426b2f10008f5a3c2f56af92',1,'SWIGTYPE_p_f_int_p_double_p_double__void():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ae94c3b6e426b2f10008f5a3c2f56af92',1,'SWIGTYPE_p_f_int_p_double_p_double__void():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ae94c3b6e426b2f10008f5a3c2f56af92',1,'SWIGTYPE_p_f_int_p_double_p_double__void():&#160;plplotcPYTHON_wrap.c']]],
  ['swigtype_5fp_5ff_5fint_5fp_5fq_5fconst_5f_5fdouble_5fp_5fq_5fconst_5f_5fdouble_5f_5fvoid',['SWIGTYPE_p_f_int_p_q_const__double_p_q_const__double__void',['../plplotluacLUA__wrap_8c.html#a5f4f8d97e6e3d08d8690b7f64d05e93e',1,'SWIGTYPE_p_f_int_p_q_const__double_p_q_const__double__void():&#160;plplotluacLUA_wrap.c'],['../plplotcPYTHON__wrap_8c.html#a5f4f8d97e6e3d08d8690b7f64d05e93e',1,'SWIGTYPE_p_f_int_p_q_const__double_p_q_const__double__void():&#160;plplotcPYTHON_wrap.c']]],
  ['swigtype_5fp_5fint',['SWIGTYPE_p_int',['../plplotluacLUA__wrap_8c.html#a73413c3e668627181e90558738caccd5',1,'SWIGTYPE_p_int():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a73413c3e668627181e90558738caccd5',1,'SWIGTYPE_p_int():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a73413c3e668627181e90558738caccd5',1,'SWIGTYPE_p_int():&#160;plplotcPYTHON_wrap.c']]],
  ['swigtype_5fp_5fp_5fchar',['SWIGTYPE_p_p_char',['../plplotluacLUA__wrap_8c.html#ae62a09763b43a6f895de430344a26b80',1,'SWIGTYPE_p_p_char():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ae62a09763b43a6f895de430344a26b80',1,'SWIGTYPE_p_p_char():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ae62a09763b43a6f895de430344a26b80',1,'SWIGTYPE_p_p_char():&#160;plplotcPYTHON_wrap.c']]],
  ['swigtype_5fp_5fp_5fdouble',['SWIGTYPE_p_p_double',['../plplotluacLUA__wrap_8c.html#a9ca4064d87fbf44deefc2a6a15e6ab2f',1,'SWIGTYPE_p_p_double():&#160;plplotluacLUA_wrap.c'],['../plplotcPYTHON__wrap_8c.html#a9ca4064d87fbf44deefc2a6a15e6ab2f',1,'SWIGTYPE_p_p_double():&#160;plplotcPYTHON_wrap.c']]],
  ['swigtype_5fp_5fplcgrid',['SWIGTYPE_p_PLcGrid',['../plplotcPYTHON__wrap_8c.html#a31eb04c55a134e38b43ab1cf19521d5f',1,'plplotcPYTHON_wrap.c']]],
  ['swigtype_5fp_5fplcgrid2',['SWIGTYPE_p_PLcGrid2',['../plplotcPYTHON__wrap_8c.html#aff212a71284c2334decc63896e7e8cb5',1,'plplotcPYTHON_wrap.c']]],
  ['swigtype_5fp_5fplgraphicsin',['SWIGTYPE_p_PLGraphicsIn',['../plplotluacLUA__wrap_8c.html#a2a00b161b1ee44d933693f234ca003e5',1,'SWIGTYPE_p_PLGraphicsIn():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a2a00b161b1ee44d933693f234ca003e5',1,'SWIGTYPE_p_PLGraphicsIn():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a2a00b161b1ee44d933693f234ca003e5',1,'SWIGTYPE_p_PLGraphicsIn():&#160;plplotcPYTHON_wrap.c']]],
  ['swigtype_5fp_5funsigned_5fint',['SWIGTYPE_p_unsigned_int',['../plplotluacLUA__wrap_8c.html#ac97b19aa5dc7dde3dfd22b663edbca22',1,'SWIGTYPE_p_unsigned_int():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#ac97b19aa5dc7dde3dfd22b663edbca22',1,'SWIGTYPE_p_unsigned_int():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#ac97b19aa5dc7dde3dfd22b663edbca22',1,'SWIGTYPE_p_unsigned_int():&#160;plplotcPYTHON_wrap.c']]],
  ['swigunused',['SWIGUNUSED',['../plplotluacLUA__wrap_8c.html#a6ee41cd160d397aa76668bf4db65e2d1',1,'SWIGUNUSED():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a6ee41cd160d397aa76668bf4db65e2d1',1,'SWIGUNUSED():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a6ee41cd160d397aa76668bf4db65e2d1',1,'SWIGUNUSED():&#160;plplotcPYTHON_wrap.c']]],
  ['swigunusedparm',['SWIGUNUSEDPARM',['../plplotluacLUA__wrap_8c.html#a6a54164d0685c632e7540c5ad32a453a',1,'SWIGUNUSEDPARM():&#160;plplotluacLUA_wrap.c'],['../plplot__octaveOCTAVE__wrap_8cxx.html#a6a54164d0685c632e7540c5ad32a453a',1,'SWIGUNUSEDPARM():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a6a54164d0685c632e7540c5ad32a453a',1,'SWIGUNUSEDPARM():&#160;plplotcPYTHON_wrap.c']]],
  ['swigversion',['SWIGVERSION',['../plplot__octaveOCTAVE__wrap_8cxx.html#a82758940324a80fe482f130cc097c36e',1,'SWIGVERSION():&#160;plplot_octaveOCTAVE_wrap.cxx'],['../plplotcPYTHON__wrap_8c.html#a82758940324a80fe482f130cc097c36e',1,'SWIGVERSION():&#160;plplotcPYTHON_wrap.c']]],
  ['switch_5fto_5fgraph',['SWITCH_TO_GRAPH',['../metadefs_8h.html#ac4382ab45a4cecf92033fac1f49c06e3',1,'metadefs.h']]],
  ['switch_5fto_5ftext',['SWITCH_TO_TEXT',['../metadefs_8h.html#aaa8308d7392d97bc8f8a6efd6ff90466',1,'metadefs.h']]],
  ['sym_5flen',['SYM_LEN',['../test-drv-info_8c.html#ae0e57cdba5cf243eb087316183cca438',1,'test-drv-info.c']]]
];
